@@ -1,4 +1,5 @@
 <?php
+
 /*
  * This file is part of the Symfony package.
  *
@@ -37,17 +38,17 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     private $parentAcl;
     private $permissionGrantingStrategy;
     private $objectIdentity;
-    private $classAces;
-    private $classFieldAces;
-    private $objectAces;
-    private $objectFieldAces;
+    private $classAces = array();
+    private $classFieldAces = array();
+    private $objectAces = array();
+    private $objectFieldAces = array();
     private $id;
     private $loadedSids;
     private $entriesInheriting;
-    private $listeners;
+    private $listeners = array();
 
     /**
-     * Constructor
+     * Constructor.
      *
      * @param int                                 $id
      * @param ObjectIdentityInterface             $objectIdentity
@@ -62,16 +63,10 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
         $this->permissionGrantingStrategy = $permissionGrantingStrategy;
         $this->loadedSids = $loadedSids;
         $this->entriesInheriting = $entriesInheriting;
-        $this->parentAcl = null;
-        $this->classAces = array();
-        $this->classFieldAces = array();
-        $this->objectAces = array();
-        $this->objectFieldAces = array();
-        $this->listeners = array();
     }
 
     /**
-     * Adds a property changed listener
+     * Adds a property changed listener.
      *
      * @param PropertyChangedListener $listener
      */
@@ -256,7 +251,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     }
 
     /**
-     * Implementation for the \Serializable interface
+     * Implementation for the \Serializable interface.
      *
      * @return string
      */
@@ -276,7 +271,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     }
 
     /**
-     * Implementation for the \Serializable interface
+     * Implementation for the \Serializable interface.
      *
      * @param string $serialized
      */
@@ -395,15 +390,16 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     }
 
     /**
-     * Deletes an ACE
+     * Deletes an ACE.
+     *
+     * @param string $property
+     * @param int    $index
      *
-     * @param string  $property
-     * @param int     $index
      * @throws \OutOfBoundsException
      */
     private function deleteAce($property, $index)
     {
-        $aces = & $this->$property;
+        $aces = &$this->$property;
         if (!isset($aces[$index])) {
             throw new \OutOfBoundsException(sprintf('The index "%d" does not exist.', $index));
         }
@@ -413,22 +409,23 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
         $this->$property = array_values($this->$property);
         $this->onPropertyChanged($property, $oldValue, $this->$property);
 
-        for ($i = $index,$c = count($this->$property); $i<$c; $i++) {
-            $this->onEntryPropertyChanged($aces[$i], 'aceOrder', $i+1, $i);
+        for ($i = $index, $c = count($this->$property); $i < $c; ++$i) {
+            $this->onEntryPropertyChanged($aces[$i], 'aceOrder', $i + 1, $i);
         }
     }
 
     /**
-     * Deletes a field-based ACE
+     * Deletes a field-based ACE.
+     *
+     * @param string $property
+     * @param int    $index
+     * @param string $field
      *
-     * @param string  $property
-     * @param int     $index
-     * @param string  $field
      * @throws \OutOfBoundsException
      */
     private function deleteFieldAce($property, $index, $field)
     {
-        $aces = & $this->$property;
+        $aces = &$this->$property;
         if (!isset($aces[$field][$index])) {
             throw new \OutOfBoundsException(sprintf('The index "%d" does not exist.', $index));
         }
@@ -438,13 +435,13 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
         $aces[$field] = array_values($aces[$field]);
         $this->onPropertyChanged($property, $oldValue, $this->$property);
 
-        for ($i = $index,$c = count($aces[$field]); $i<$c; $i++) {
-            $this->onEntryPropertyChanged($aces[$field][$i], 'aceOrder', $i+1, $i);
+        for ($i = $index, $c = count($aces[$field]); $i < $c; ++$i) {
+            $this->onEntryPropertyChanged($aces[$field][$i], 'aceOrder', $i + 1, $i);
         }
     }
 
     /**
-     * Inserts an ACE
+     * Inserts an ACE.
      *
      * @param string                    $property
      * @param int                       $index
@@ -452,6 +449,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
      * @param SecurityIdentityInterface $sid
      * @param bool                      $granting
      * @param string                    $strategy
+     *
      * @throws \OutOfBoundsException
      * @throws \InvalidArgumentException
      */
@@ -473,7 +471,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
             }
         }
 
-        $aces = & $this->$property;
+        $aces = &$this->$property;
         $oldValue = $this->$property;
         if (isset($aces[$index])) {
             $this->$property = array_merge(
@@ -482,8 +480,8 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
                 array_slice($this->$property, $index)
             );
 
-            for ($i = $index,$c = count($this->$property)-1; $i<$c; $i++) {
-                $this->onEntryPropertyChanged($aces[$i+1], 'aceOrder', $i, $i+1);
+            for ($i = $index, $c = count($this->$property) - 1; $i < $c; ++$i) {
+                $this->onEntryPropertyChanged($aces[$i + 1], 'aceOrder', $i, $i + 1);
             }
         }
 
@@ -492,7 +490,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     }
 
     /**
-     * Inserts a field-based ACE
+     * Inserts a field-based ACE.
      *
      * @param string                    $property
      * @param int                       $index
@@ -501,6 +499,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
      * @param SecurityIdentityInterface $sid
      * @param bool                      $granting
      * @param string                    $strategy
+     *
      * @throws \InvalidArgumentException
      * @throws \OutOfBoundsException
      */
@@ -522,7 +521,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
             }
         }
 
-        $aces = & $this->$property;
+        $aces = &$this->$property;
         if (!isset($aces[$field])) {
             $aces[$field] = array();
         }
@@ -539,8 +538,8 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
                 array_slice($aces[$field], $index)
             );
 
-            for ($i = $index,$c = count($aces[$field])-1; $i<$c; $i++) {
-                $this->onEntryPropertyChanged($aces[$field][$i+1], 'aceOrder', $i, $i+1);
+            for ($i = $index, $c = count($aces[$field]) - 1; $i < $c; ++$i) {
+                $this->onEntryPropertyChanged($aces[$field][$i + 1], 'aceOrder', $i, $i + 1);
             }
         }
 
@@ -549,17 +548,18 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     }
 
     /**
-     * Updates an ACE
+     * Updates an ACE.
+     *
+     * @param string $property
+     * @param int    $index
+     * @param int    $mask
+     * @param string $strategy
      *
-     * @param string  $property
-     * @param int     $index
-     * @param int     $mask
-     * @param string  $strategy
      * @throws \OutOfBoundsException
      */
     private function updateAce($property, $index, $mask, $strategy = null)
     {
-        $aces = & $this->$property;
+        $aces = &$this->$property;
         if (!isset($aces[$index])) {
             throw new \OutOfBoundsException(sprintf('The index "%d" does not exist.', $index));
         }
@@ -576,12 +576,13 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     }
 
     /**
-     * Updates auditing for an ACE
+     * Updates auditing for an ACE.
+     *
+     * @param array &$aces
+     * @param int   $index
+     * @param bool  $auditSuccess
+     * @param bool  $auditFailure
      *
-     * @param array   &$aces
-     * @param int     $index
-     * @param bool    $auditSuccess
-     * @param bool    $auditFailure
      * @throws \OutOfBoundsException
      */
     private function updateAuditing(array &$aces, $index, $auditSuccess, $auditFailure)
@@ -602,13 +603,14 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     }
 
     /**
-     * Updates a field-based ACE
+     * Updates a field-based ACE.
+     *
+     * @param string $property
+     * @param int    $index
+     * @param string $field
+     * @param int    $mask
+     * @param string $strategy
      *
-     * @param string  $property
-     * @param int     $index
-     * @param string  $field
-     * @param int     $mask
-     * @param string  $strategy
      * @throws \InvalidArgumentException
      * @throws \OutOfBoundsException
      */
@@ -618,7 +620,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
             throw new \InvalidArgumentException('$field cannot be empty.');
         }
 
-        $aces = & $this->$property;
+        $aces = &$this->$property;
         if (!isset($aces[$field][$index])) {
             throw new \OutOfBoundsException(sprintf('The index "%d" does not exist.', $index));
         }
@@ -635,7 +637,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     }
 
     /**
-     * Called when a property of the ACL changes
+     * Called when a property of the ACL changes.
      *
      * @param string $name
      * @param mixed  $oldValue
@@ -649,7 +651,7 @@ class Acl implements AuditableAclInterface, NotifyPropertyChanged
     }
 
     /**
-     * Called when a property of an ACE associated with this ACL changes
+     * Called when a property of an ACE associated with this ACL changes.
      *
      * @param EntryInterface $entry
      * @param string         $name
